# Copyrights 2010-2013 by [Mark Overmeer].
#  For other contributors see ChangeLog.
# See the manual pages for details on the licensing terms.
# Pod stripped from pm file by OODoc 2.01.
package XML::Compile::WSA;
use vars '$VERSION';
$VERSION = '0.90';


# Stuff from ::SOAP::WSA should move here

1;
